%define enable_external_acl_helpers 1

Summary: The Squid proxy caching server.
Name: squid
Version: 2.5.STABLE10
Release: 1tr
License: GPL
Group: Trustix Official
Source: http://www.squid-cache.org/Versions/v2/2.5/squid-%{version}.tar.bz2
Source2: squid.init
Source3: squid.logrotate
Patch1: squid-2.5-config.patch
Patch2: squid-2.5.STABLE6-icap.patch.gz
Patch3: squid-2.5.STABLE5-sambaprefix.patch
Patch4: squid-2.5.STABLE7-gopher_html_parsing.patch
Patch5: squid-2.5.STABLE7-wccp_denial_of_service.patch
Patch6: squid-2.5.STABLE7-fakeauth_auth.patch
Patch7: squid-2.5.STABLE8-dns_assert.patch
BuildRoot: /var/tmp/%{name}-root
Prereq: chkconfig logrotate shadow-utils tsl-utils
BuildRequires: perl

%description
Squid is a high-performance proxy caching server for Web clients,
supporting FTP, gopher, and HTTP data objects. Unlike traditional
caching software, Squid handles all requests in a single,
non-blocking, I/O-driven process. Squid keeps meta data and especially
hot objects cached in RAM, caches DNS lookups, supports non-blocking
DNS lookups, and implements negative caching of failed requests.

Squid consists of a main server program squid, a program for retrieving
FTP data (ftpget), and some management and client tools.

Install squid if you need a proxy caching server.

%prep
%setup -q
%patch1 -p1
#%patch2 -p1
%patch3 -p1
#%patch4 -p1
#%patch5 -p1
#%patch6 -p1
#%patch7 -p1

# Fix path
perl -pi -e 's/\/usr\/local\/bin\/perl/\/usr\/bin\/perl/' `find . -type f`

%build
#CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr \
#   --exec_prefix=/usr --bindir=/usr/sbin --libexecdir=/usr/lib/squid \
#   --localstatedir=/var/spool/squid --sysconfdir=/etc/squid --enable-async-io \
#   --enable-poll --mandir='${prefix}/share/man' # --enable-icmp

# Sigh
autoconf >/dev/null 2>&1 ||:

# --enable-basic-auth-helpers="SASL" does not work as it is written for
# sasl v1
%configure --bindir=/usr/sbin \
   --libexecdir=/usr/lib/squid \
   --localstatedir=/var/spool/squid \
   --sysconfdir=/etc/squid \
   --enable-async-io \
   --enable-poll \
   --with-dl \
   --enable-gnuregex \
   --enable-carp \
   --with-aio \
   --enable-icap-support \
   --enable-delay-pools \
   --enable-useragent-log \
   --enable-referer-log \
   --enable-arp-acl \
   --enable-htcp \
   --enable-ssl \
   --with-openssl \
   --enable-forw-via-db \
   --enable-cache-digests \
   --enable-default-err-language="English" \
   --enable-linux-netfilter \
   --enable-auth="ntlm basic digest" \
   --enable-basic-auth-helpers="MSNT NCSA PAM SMB YP getpwnam multi-domain-NTLM winbind" \
   --enable-ntlm-auth-helpers="SMB fakeauth no_check winbind" \
   --enable-digest-auth-helpers="password" \
   --enable-ntlm-fail-open \
%if %{enable_external_acl_helpers}
   --enable-external-acl-helpers="ip_user unix_group wbinfo_group winbind_group ldap_group" \
%endif
   --enable-x-accelerator-vary \
   --enable-snmp
#  --enable-err-languages \
#  --enable-icmp \

# Seems it needs a little help
echo "#define STDC_HEADERS 1" >> include/autoconf.h
   
export logdir=/var/log/squid
export libexecdir=/usr/lib/squid
export sysconfdir=/etc/squid

DEFAULTS="DEFAULT_CACHE_LOG=${logdir}/cache.log \
          DEFAULT_ACCESS_LOG=${logdir}/access.log \
          DEFAULT_STORE_LOG=${logdir}/store.log \
          DEFAULT_PID_FILE=/var/run/squid.pid \
          DEFAULT_SWAP_DIR=/var/spool/squid \
          DEFAULT_ICON_DIR=${libexecdir}/icons \
          DEFAULT_ERROR_DIR=${libexecdir}/errors/English \
          DEFAULT_MIME_TABLE=${libexecdir}/mime.conf \
          DEFAULT_MIB_PATH=/usr/lib/squid/mib.txt"

make ${DEFAULTS}

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"
make install  \
	prefix=/usr \
	sysconfdir=/etc/squid \
	localstatedir=/var/spool/squid \
	bindir=/usr/sbin \
	sbindir=/usr/sbin \
	libexecdir=/usr/lib/squid \
        icondir=/usr/lib/squid/icons \
	DESTDIR=$RPM_BUILD_ROOT
#install -m 4750 src/pinger $RPM_BUILD_ROOT/usr/lib/squid

cd errors
rm -rf $RPM_BUILD_ROOT/etc/squid/errors
mkdir -p $RPM_BUILD_ROOT/usr/lib/squid/errors
for i in *; do
   if [ -d $i ]; then
       mkdir -p $RPM_BUILD_ROOT/usr/lib/squid/errors/$i
       install -m 644 $i/* $RPM_BUILD_ROOT/usr/lib/squid/errors/$i
   fi
done
ln -s /usr/lib/squid/errors/English $RPM_BUILD_ROOT/etc/squid/errors

mkdir -p $RPM_BUILD_ROOT/etc/init.d
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m 755 $RPM_SOURCE_DIR/squid.init $RPM_BUILD_ROOT/etc/init.d/squid
install -m 644 $RPM_SOURCE_DIR/squid.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/squid

mkdir -p $RPM_BUILD_ROOT/var/log/squid
mkdir -p $RPM_BUILD_ROOT/var/spool/squid

strip $RPM_BUILD_ROOT/usr/sbin/* \
      $RPM_BUILD_ROOT/usr/lib/squid/* || :

ln -s /etc/squid/mime.conf $RPM_BUILD_ROOT/usr/lib/squid/mime.conf

%pre
if [ -z "`getent group squid`" ] ; then
	/usr/sbin/groupadd -g 23 squid 
fi
if [ -z "`getent passwd squid`" ] ; then
	/usr/sbin/useradd -u 23 -g squid -M -d /no/dir -s /dev/null squid
fi

for i in /var/{log/squid,spool/squid} ; do
	if [ -d $i ] ; then
		for adir in `find $i -maxdepth 0 \! -user squid`; do
			chown -R squid.squid $adir
		done
	fi
done

exit 0

%post
if [ $1 = 0 ]; then
 ln -snf /usr/lib/squid/errors/$DIR /etc/squid/errors
fi
/sbin/chkconfig --add squid
# Restart service after upgrade.
/sbin/restart_maybe squid

%preun
if [ $1 = 0 ] ; then
	rm -f /var/log/squid/*
	/sbin/chkconfig --del squid
	%{_initdir}/squid stop || :
fi


%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,0755)
%config(noreplace) /etc/squid/*.conf
%dir /etc/squid
/etc/squid/*.default
/etc/squid/errors
/usr/lib/squid
/usr/sbin/RunAccel
/usr/sbin/RunCache
/usr/sbin/squid
/usr/sbin/squidclient
/etc/init.d/squid
/usr/share/man/man8/*
%config(noreplace) /etc/logrotate.d/squid
%doc doc/*
%doc CONTRIBUTORS COPYING COPYRIGHT CREDITS ChangeLog INSTALL
%doc QUICKSTART README RELEASENOTES.html SPONSORS helpers/*/*/*.conf
%attr(750,squid,squid) %dir /var/log/squid
%attr(750,squid,squid) %dir /var/spool/squid

%changelog
* Mon May 23 2005 Ajith Thampi <ajith at comodo dot com> 2.5.STABLE10-1tr
- New Upstream
- Fixed a Set-Cookie race condition causing inconsistent cache behaviour
- Abort on misconfigured http_access rules to prevent unexpected results from partial configuration
- FTP directory listings corrected again (broken by 2.5.STABLE9)
- Support for proxying huge objects greater than 2GB in size		

* Thu May 12 2005 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE9-3tr
- Now --enable-snmp again.

* Thu May 12 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.5.STABLE9-2tr
- Security Fix: A vulnerability has been reported in Squid, which can be exploited by
  malicious people to spoof DNS lookups.

  The vulnerability is caused due to an unspecified error in the DNS client when handling
  DNS responses and can be exploited to spoof DNS lookups.

* Mon May  9 2005 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE9-1tr
- Squid 2.5.STABLE9 and earlier does not trigger a fatal error when it
  identifies missing or invalid ACLs in the http_access configuration,
  which could lead to less restrictive ACLs than intended by the
  administrator.

  The Common Vulnerabilities and Exposures project (cve.mitre.org) has
  assigned the name CAN-2005-1345 to this issue.

* Thu Oct 14 2004 Oystein Viggen <oysteivi at trustix dot com> 2.5.STABLE5-7tr
- Patch a crash bug in snmp server

* Thu Sep 16 2004 Oystein Viggen <oysteivi at trustix dot com> 2.5.STABLE5-6tr
- Another security fix for the ntlm auth helper (CAN-2004-0832)

* Thu Jun 10 2004 Oystein Viggen <oysteivi at trustix dot com> 2.5.STABLE5-5tr
- Security fix for ntlm auth helper (CAN-2004-0541)

* Fri Apr 23 2004 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE5-4tr
- Now use /usr for SAMBAPREFIX.  Patch 3.

* Fri Apr 16 2004 Oystein Viggen <oysteivi at trustix dot com> 2.5.STABLE5-3tr
- Turn off external acl helpers to help porting.
  (please turn this back on later when openldap and samba are available)

* Tue Mar  2 2004 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE5-1tr
- New upstream.

* Wed Feb 25 2004 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE4-4tr
- Now with ICAP support.

* Mon Feb  2 2004 Chr. Toldnes <christht at tihlde dot org> 2.5.STABLE4-2tr
- chkconfig --add in %post

* Tue Dec  9 2003 Erlend Midttun <erlendbm at trustix dot org> 2.5.STABLE4-1tr
- New upstream.

* Mon Jun 30 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE3-1tr
- Rebuilt with -tr.

* Mon Jun 30 2003 Janke Rnnblom <janron at trustix dot org> 2.5.STABLE3-1jr
- Update to 2.5.STABLE3

* Thu Jun 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE2-5tr
- Added [  OK  ] and [FAILURE] to startup script. Take II.

* Thu Jun 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE2-4tr
- Added [  OK  ] and [FAILURE] to startup script.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE2-3tr
- Big rebuild

* Mon May 05 2003 Frode Ramsvik <froder at trustix dot com> 2.5.STABLE2-2fr
- Don't create home directory when adding user squid.
- No need to call groupdel after un-install.

* Wed Apr 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE2-1em
- Initscript now works.
- New upstream.
- Fix icon path.

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE1-4em
- Rebuilt against glibc 2.3.2.

* Thu Jan 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.5.STABLE1-3em
- Added SSL patch.

* Fri Nov  1 2002 Christian H. Toldnes <christht at trustix dot com> 2.5.STABLE1-2ct
- Fixed user/group generation.
- Moved from /etc/rc.d/init.d to /etc/init.d
- Now uses $INITLOCK for lockfile.

* Fri Oct 11 2002 Erlend Midttun <erlendbm at trustix dot com>
- Picked up 2.5STABLE1.

* Wed Jul 04 2002 Nico Erfurth <masta at trustix dot org> 2.4.STABLE7-1tr
- Upgraded to 2.4.STABLE7, includes security fixes
- Some spec cleanups.

* Wed Mar 27 2002 Christian H. Toldnes <christht at trustix dot com>
- Picked up 2.4.STABLE6 which is a security fix.

* Fri Feb 22 2002 Erlend Midttun <erlendbm at trustix dot com>
- Updated to 2.4.STABLE4 to fix security holes.

* Wed Aug 15 2001 Oystein Viggen <oysteivi at trustix dot com>
- Fixed wrong cachedir in default config.

* Fri Apr 20 2001 Erlend Midttun <erlendbm at trustix dot com>
- Fixed path to perl in support programs.

* Tue Apr 17 2001 Erlend Midttun <erlendbm at trustix dot com>
- Updated to 2.4.STABLE1
- Added bugfix-patches up to current.

* Fri Jan 12 2001 Oystein Viggen <oysteivi at trustix dot com>
- Added a patch for insecure tempfiles

* Wed Sep 13 2000 Per Ivar Paulsen <perp at trustix dot com>
- Picked up STABLE4

* Fri Jun 23 2000 Erlend Midttun <erlendbm at trustix dot com>
- Fixed some group problems

* Wed May  3 2000 Erlend Midttun <erlendbm at trustix dot com>
- Upgraded to version STABLE2

* Fri Feb 25 2000 Lars Gaarden <larsg at trustix dot com>
- Changed group ownership on /var/log/squid and /var/spool/squid

* Tue Jan 25 2000 Per Ivar Paulsen <perp at trustix dot com>
- Initial release for the Trustix Secure Linux distribution.
- Added noreplace.
- Moved man and info pages to /usr/share adhering to FHS
- TODO: add better default configuration

* Mon Jan 10 2000 Bill Nottingham <notting@redhat.com>
- 2.3.STABLE1 (whee, another serial number)

* Tue Dec 21 1999 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix compliance with ftp RFCs
  (http://www.wu-ftpd.org/broken-clients.html)
- Work around a bug in some versions of autoconf
- BuildPrereq sgml-tools - we're using sgml2html

* Mon Oct 18 1999 Bill Nottingham <notting@redhat.com>
- add a couple of bugfix patches

* Wed Oct 13 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE5.
- update FAQ, fix URLs.

* Sat Sep 11 1999 Cristian Gafton <gafton@redhat.com>
- transform restart in reload and add restart to the init script

* Tue Aug 31 1999 Bill Nottingham <notting@redhat.com>
- add squid user as user 23.

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging
- fix conflict between logrotate & squid -k (#4562)

* Wed Jul 28 1999 Bill Nottingham <notting@redhat.com>
- put cachemgr.cgi back in /usr/lib/squid

* Wed Jul 14 1999 Bill Nottingham <notting@redhat.com>
- add webdav bugfix patch (#4027)

* Mon Jul 12 1999 Bill Nottingham <notting@redhat.com>
- fix path to config in squid.init (confuses linuxconf)

* Wed Jul  7 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE4

* Wed Jun 9 1999 Dale Lovelace <dale@redhat.com>
- logrotate changes
- errors from find when /var/spool/squid or
- /var/log/squid didn't exist

* Thu May 20 1999 Bill Nottingham <notting@redhat.com>
- 2.2.STABLE3

* Thu Apr 22 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE.2

* Sun Apr 18 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.STABLE1

* Thu Apr 15 1999 Bill Nottingham <notting@redhat.com>
- don't need to run groupdel on remove
- fix useradd

* Mon Apr 12 1999 Bill Nottingham <notting@redhat.com>
- fix effective_user (bug #2124)

* Mon Apr  5 1999 Bill Nottingham <notting@redhat.com>
- strip binaries

* Thu Apr  1 1999 Bill Nottingham <notting@redhat.com>
- duh. adduser does require a user name.
- add a serial number

* Tue Mar 30 1999 Bill Nottingham <notting@redhat.com>
- add an adduser in %pre, too

* Thu Mar 25 1999 Bill Nottingham <notting@redhat.com>
- oog. chkconfig must be in %preun, not %postun

* Wed Mar 24 1999 Bill Nottingham <notting@redhat.com>
- switch to using group squid
- turn off icmp (insecure)
- update to 2.2.DEVEL3
- build FAQ docs from source

* Tue Mar 23 1999 Bill Nottingham <notting@redhat.com>
- logrotate changes

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Wed Feb 10 1999 Bill Nottingham <notting@redhat.com>
- update to 2.2.PRE2

* Wed Dec 30 1998 Bill Nottingham <notting@redhat.com>
- cache & log dirs shouldn't be world readable
- remove preun script (leave logs & cache @ uninstall)

* Tue Dec 29 1998 Bill Nottingham <notting@redhat.com>
- fix initscript to get cache_dir correct

* Fri Dec 18 1998 Bill Nottingham <notting@redhat.com>
- update to 2.1.PATCH2
- merge in some changes from RHCN version

* Sat Oct 10 1998 Cristian Gafton <gafton@redhat.com>
- strip binaries
- version 1.1.22

* Sun May 10 1998 Cristian Gafton <gafton@redhat.com>
- don't make packages conflict with each other...

* Sat May 02 1998 Cristian Gafton <gafton@redhat.com>
- added a proxy auth patch from Alex deVries <adevries@engsoc.carleton.ca>
- fixed initscripts

* Thu Apr 09 1998 Cristian Gafton <gafton@redhat.com>
- rebuilt for Manhattan

* Fri Mar 20 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.21/1.NOVM.21

* Mon Mar 02 1998 Cristian Gafton <gafton@redhat.com>
- updated the init script to use reconfigure option to restart squid instead
  of shutdown/restart (both safer and quicker)

* Sat Feb 07 1998 Cristian Gafton <gafton@redhat.com>
- upgraded to 1.1.20
- added the NOVM package and tryied to reduce the mess in the spec file

* Wed Jan 7 1998 Cristian Gafton <gafton@redhat.com>
- first build against glibc
- patched out the use of setresuid(), which is available only on kernels
  2.1.44 and later

